import defaultDayjs, { Dayjs } from 'dayjs';
import { FieldFormatTokenMap, MuiPickersAdapter, AdapterFormats, AdapterUnits, AdapterOptions, PickersTimezone } from '../models';
type Constructor = (...args: Parameters<typeof defaultDayjs>) => Dayjs;
/**
 * Based on `@date-io/dayjs`
 *
 * MIT License
 *
 * Copyright (c) 2017 Dmitriy Kovalenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
export declare class AdapterDayjs implements MuiPickersAdapter<Dayjs, string> {
    isMUIAdapter: boolean;
    isTimezoneCompatible: boolean;
    lib: string;
    rawDayJsInstance: typeof defaultDayjs;
    dayjs: Constructor;
    locale?: string;
    formats: AdapterFormats;
    escapedCharacters: {
        start: string;
        end: string;
    };
    formatTokenMap: FieldFormatTokenMap;
    constructor({ locale, formats, instance }?: AdapterOptions<string, typeof defaultDayjs>);
    private setLocaleToValue;
    private hasUTCPlugin;
    private hasTimezonePlugin;
    private isSame;
    private createSystemDate;
    private createUTCDate;
    private createTZDate;
    private getLocaleFormats;
    date: (value?: any) => defaultDayjs.Dayjs | null;
    dateWithTimezone: (value: string | null | undefined, timezone: PickersTimezone) => Dayjs | null;
    getTimezone: (value: Dayjs) => string;
    setTimezone: (value: Dayjs, timezone: PickersTimezone) => Dayjs;
    toJsDate: (value: Dayjs) => Date;
    parseISO: (isoString: string) => defaultDayjs.Dayjs;
    toISO: (value: Dayjs) => string;
    parse: (value: string, format: string) => defaultDayjs.Dayjs | null;
    getCurrentLocaleCode: () => string;
    is12HourCycleInCurrentLocale: () => boolean;
    expandFormat: (format: string) => string;
    getFormatHelperText: (format: string) => string;
    isNull: (value: Dayjs | null) => boolean;
    isValid: (value: any) => boolean;
    format: (value: Dayjs, formatKey: keyof AdapterFormats) => string;
    formatByString: (value: Dayjs, formatString: string) => string;
    formatNumber: (numberToFormat: string) => string;
    getDiff: (value: Dayjs, comparing: Dayjs | string, unit?: AdapterUnits) => number;
    isEqual: (value: any, comparing: any) => boolean;
    isSameYear: (value: Dayjs, comparing: Dayjs) => boolean;
    isSameMonth: (value: Dayjs, comparing: Dayjs) => boolean;
    isSameDay: (value: Dayjs, comparing: Dayjs) => boolean;
    isSameHour: (value: Dayjs, comparing: Dayjs) => boolean;
    isAfter: (value: Dayjs, comparing: Dayjs) => boolean;
    isAfterYear: (value: Dayjs, comparing: Dayjs) => boolean;
    isAfterDay: (value: Dayjs, comparing: Dayjs) => boolean;
    isBefore: (value: Dayjs, comparing: Dayjs) => boolean;
    isBeforeYear: (value: Dayjs, comparing: Dayjs) => boolean;
    isBeforeDay: (value: Dayjs, comparing: Dayjs) => boolean;
    isWithinRange: (value: Dayjs, [start, end]: [Dayjs, Dayjs]) => boolean;
    startOfYear: (value: Dayjs) => defaultDayjs.Dayjs;
    startOfMonth: (value: Dayjs) => defaultDayjs.Dayjs;
    startOfWeek: (value: Dayjs) => defaultDayjs.Dayjs;
    startOfDay: (value: Dayjs) => defaultDayjs.Dayjs;
    endOfYear: (value: Dayjs) => defaultDayjs.Dayjs;
    endOfMonth: (value: Dayjs) => defaultDayjs.Dayjs;
    endOfWeek: (value: Dayjs) => defaultDayjs.Dayjs;
    endOfDay: (value: Dayjs) => defaultDayjs.Dayjs;
    addYears: (value: Dayjs, amount: number) => defaultDayjs.Dayjs;
    addMonths: (value: Dayjs, amount: number) => defaultDayjs.Dayjs;
    addWeeks: (value: Dayjs, amount: number) => defaultDayjs.Dayjs;
    addDays: (value: Dayjs, amount: number) => defaultDayjs.Dayjs;
    addHours: (value: Dayjs, amount: number) => defaultDayjs.Dayjs;
    addMinutes: (value: Dayjs, amount: number) => defaultDayjs.Dayjs;
    addSeconds: (value: Dayjs, amount: number) => defaultDayjs.Dayjs;
    getYear: (value: Dayjs) => number;
    getMonth: (value: Dayjs) => number;
    getDate: (value: Dayjs) => number;
    getHours: (value: Dayjs) => number;
    getMinutes: (value: Dayjs) => number;
    getSeconds: (value: Dayjs) => number;
    getMilliseconds: (value: Dayjs) => number;
    setYear: (value: Dayjs, year: number) => defaultDayjs.Dayjs;
    setMonth: (value: Dayjs, month: number) => defaultDayjs.Dayjs;
    setDate: (value: Dayjs, date: number) => defaultDayjs.Dayjs;
    setHours: (value: Dayjs, hours: number) => defaultDayjs.Dayjs;
    setMinutes: (value: Dayjs, minutes: number) => defaultDayjs.Dayjs;
    setSeconds: (value: Dayjs, seconds: number) => defaultDayjs.Dayjs;
    setMilliseconds: (value: Dayjs, milliseconds: number) => defaultDayjs.Dayjs;
    getDaysInMonth: (value: Dayjs) => number;
    getNextMonth: (value: Dayjs) => defaultDayjs.Dayjs;
    getPreviousMonth: (value: Dayjs) => defaultDayjs.Dayjs;
    getMonthArray: (value: Dayjs) => defaultDayjs.Dayjs[];
    mergeDateAndTime: (dateParam: Dayjs, timeParam: Dayjs) => defaultDayjs.Dayjs;
    getWeekdays: () => string[];
    getWeekArray: (value: Dayjs) => defaultDayjs.Dayjs[][];
    getWeekNumber: (value: Dayjs) => number;
    getYearRange: (start: Dayjs, end: Dayjs) => defaultDayjs.Dayjs[];
    getMeridiemText: (ampm: 'am' | 'pm') => "AM" | "PM";
}
export {};
